@@ -1,4 +1,5 @@
 from datetime import datetime
+from socket import gethostbyaddr
 
 from django.db import models
 from django.contrib.auth.models import User
@@ -22,9 +23,9 @@ class Request(models.Model):
     # User infomation
     ip = models.IPAddressField(_('ip address'))
     user = models.ForeignKey(User, blank=True, null=True)
-    referer = models.URLField(_('referer'), verify_exists=False, blank=True, null=True)
+    referer = models.URLField(_('referer'), verify_exists=False, max_length=255, blank=True, null=True)
     user_agent = models.CharField(_('user agent'), max_length=255, blank=True, null=True)
-    language = models.CharField(_('language'), max_length=25, blank=True, null=True)
+    language = models.CharField(_('language'), max_length=255, blank=True, null=True)
     
     objects = RequestManager()
     
@@ -44,9 +45,9 @@ class Request(models.Model):
         
         # User infomation
         self.ip = request.META.get('REMOTE_ADDR', '')
-        self.referer = request.META.get('HTTP_REFERER', '')
-        self.user_agent = request.META.get('HTTP_USER_AGENT', '')
-        self.language = request.META.get('HTTP_ACCEPT_LANGUAGE', '')
+        self.referer = request.META.get('HTTP_REFERER', '')[:255]
+        self.user_agent = request.META.get('HTTP_USER_AGENT', '')[:255]
+        self.language = request.META.get('HTTP_ACCEPT_LANGUAGE', '')[:255]
         
         if getattr(request, 'user', False):
             if request.user.is_authenticated():
@@ -81,3 +82,11 @@ class Request(models.Model):
         if self._keywords:
             return ' '.join(self._keywords[1]['keywords'].split('+'))
     keywords = property(keywords)
+    
+    #@property
+    def hostname(self):
+        try:
+            return gethostbyaddr(self.ip)[0]
+        except Exception: # socket.gaierror, socket.herror, etc
+            return self.ip
+    hostname = property(hostname)
