@@ -1,6 +1,4 @@
 import re
-from django.core.cache import cache
-from django.utils.hashcompat import sha_constructor
 
 class RegexPattern(object):
     def __init__(self, regex, name=''):
@@ -24,14 +22,8 @@ class patterns(object):
                 self.patterns.append(RegexPattern(*pattern))
     
     def resolve(self, name):
-        key = 'request.%s' % sha_constructor(name).hexdigest()
-        c = cache.get(key)
-        if (c):
-            return c
-        
         for pattern in self.patterns:
             match = pattern.resolve(name)
             if match:
-                cache.set(key, match)
                 return match
         return self.unknown
\ No newline at end of file
