@@ -1,5 +1,7 @@
 import re
 
+from time import mktime
+
 from django.utils.translation import ugettext, ugettext_lazy as _
 from django.db.models import Count
 from django.utils.translation import string_concat
@@ -45,7 +47,7 @@ class Modules(object):
         return [(module.verbose_name_plural, [module.count(qs) for qs in queries]) for module in self.modules]
     
     def graph(self, days):
-        return [{'data':[(int(day.strftime("%s"))*1000, module.count(qs)) for day, qs in days], 'label':ugettext(module.verbose_name_plural)} for module in self.modules]
+        return [{'data':[(mktime(day.timetuple())*1000, module.count(qs)) for day, qs in days], 'label':ugettext(module.verbose_name_plural)} for module in self.modules]
 
 modules = Modules()
 
@@ -64,6 +66,12 @@ class Ajax(Module):
     def count(self, qs):
         return qs.filter(is_ajax=True).count()
 
+class NotAjax(Module):
+    verbose_name_plural = 'Not Ajax'
+    
+    def count(self, qs):
+        return qs.filter(is_ajax=False).count()
+
 class Error(Module):
     def count(self, qs):
         return qs.filter(response__gte=400).count()
@@ -88,6 +96,12 @@ class Secure(Module):
     def count(self, qs):
         return qs.filter(is_secure=True).count()
 
+class Unsecure(Module):
+    verbose_name_plural = _('Unsecure')
+    
+    def count(self, qs):
+        return qs.filter(is_secure=False).count()
+
 class UniqueVisit(Module):
     def count(self, qs):
         return qs.exclude(referer__startswith=settings.REQUEST_BASE_URL).count()
